# rfiletype-py

![CI](https://github.com/messense/rfiletype-py/workflows/CI/badge.svg)
[![PyPI](https://img.shields.io/pypi/v/rfiletype.svg)](https://pypi.org/project/rfiletype)

[infer](https://github.com/bojand/infer) Python binding, infer file and MIME
type by checking the magic number signature.

## Installation

```bash
pip install rfiletype
```

## License

This work is released under the MIT license. A copy of the license is provided in the [LICENSE](./LICENSE) file.
